@@ -1410,6 +1410,18 @@ int calc_melee_bonus(int hand)
 				bonus += (5 + (p_ptr->lev / 5));
 	}
 
+	if (p_ptr->realm1 == REALM_HEX)
+	{
+		u32b f1, f2, f3;
+		object_type *o_ptr = &inventory[slot];
+		object_flags(o_ptr, &f1, &f2, &f3);
+
+		if (cursed_p(o_ptr)) bonus += 5;
+		if (f3 & TR3_HEAVY_CURSE) bonus += 7;
+		if (f3 & TR3_PERMA_CURSE) bonus += 13;
+		if (f3 & TR3_TY_CURSE) bonus += 5;
+	}
+
 	/* two handed combat gives melee penalty according to a weight of weapon */
 	if (is_two_handed())
 	{
@@ -1785,6 +1797,8 @@ static void py_attack_aux(int y, int x, int mode)
 	bool            backstab = FALSE;
 	bool            stab_fleeing = FALSE;
 
+	/* Hex */
+	bool            runesword = (is_keeping_spell(MS_RUNESWORD)) ? TRUE : FALSE;
 
 	/* Disturb the player */
 	disturb(0, 0);
@@ -1811,7 +1825,8 @@ static void py_attack_aux(int y, int x, int mode)
 		if (inventory[INVEN_WIELD].name1 == ART_STORMBRINGER ||
 			inventory[INVEN_ARM].name1 == ART_STORMBRINGER ||
 			inventory[INVEN_WIELD].name2 == EGO_WEIRD ||
-			inventory[INVEN_ARM].name2 == EGO_WEIRD)
+			inventory[INVEN_ARM].name2 == EGO_WEIRD ||
+			(runesword))
 		{
 #ifdef JP
 			msg_format("Ϥ϶ߤ%s򹶷⤷", m_name);
@@ -1969,7 +1984,7 @@ static void py_attack_aux(int y, int x, int mode)
 				}
 
 				/* Vampiric drain */
-				if ((f1 & TR1_VAMPIRIC) || (chaos_effect == 1))
+				if ((f1 & TR1_VAMPIRIC) || (chaos_effect == 1) || is_keeping_spell(MS_VAMPIRIC_ATTACK))
 				{
 					/* Only drain "living" monsters */
 					if (monster_living(r_ptr))
@@ -1978,7 +1993,7 @@ static void py_attack_aux(int y, int x, int mode)
 						can_drain = FALSE;
 				}
 
-				if (((f1 & TR1_VORPAL) || (mode == ATTACK_VORPAL)) && (randint1((o_ptr->name1 == ART_VORPAL_BLADE) ? 3 : 6) == 1))
+				if (((f1 & TR1_VORPAL) || (mode == ATTACK_VORPAL) || (runesword)) && (randint1((o_ptr->name1 == ART_VORPAL_BLADE) ? 3 : 6) == 1))
 					vorpal_cut = TRUE;
 				else vorpal_cut = FALSE;
 
@@ -2117,7 +2132,32 @@ static void py_attack_aux(int y, int x, int mode)
 				/* No negative damage */
 				if (k < 0) k = 0;
 
-				if (mode == ATTACK_TOUKI){
+				/* Hex */
+				if (runesword)
+				{
+					int bonus = 0;
+
+					if (cursed_p(o_ptr))
+					{
+						bonus += 5;
+						if (f3 & TR3_HEAVY_CURSE) bonus += 7;
+						if (f3 & TR3_PERMA_CURSE) bonus += 13;
+					}
+
+					bonus += (p_ptr->mhp - p_ptr->chp) / 10;
+
+					k += bonus;
+					drain_result += bonus;
+
+					if (r_ptr->flags3 & RF3_GOOD)
+					{
+						k *= 2;
+						drain_result *= 2;
+					}
+				}
+
+				if ((mode == ATTACK_TOUKI) || (runesword))
+				{
 				/* ATTACK_TOUKI bypass invulnerability */
 					if (m_ptr->invulner)
 	#ifdef JP
@@ -2220,7 +2260,7 @@ static void py_attack_aux(int y, int x, int mode)
 				}
 
 				/* Confusion attack */
-				if (p_ptr->confusing || (chaos_effect == 3))
+				if (p_ptr->confusing || (chaos_effect == 3) || is_keeping_spell(MS_CONFUSION))
 				{
 					/* Cancel glowing hands */
 					if (p_ptr->confusing)
@@ -4816,3 +4856,144 @@ void run_step(int dir)
 
 #endif /* ALLOW_EASY_DISARM -- TNB */
 }
+
+
+#ifdef TRAVEL
+/*
+ * Test for traveling
+ */
+static bool travel_test(void)
+{
+	int prev_dir, new_dir, check_dir = 0;
+	int row, col;
+	int i, max;
+	bool stop = TRUE;
+	cave_type *c_ptr;
+
+	/* Where we came from */
+	prev_dir = find_prevdir;
+
+	/* Range of newly adjacent grids */
+	max = (prev_dir & 0x01) + 1;
+
+	for (i = 0; i < 8; i++)
+	{
+		if (travel.cost[py+ddy_ddd[i]][px+ddx_ddd[i]] < travel.cost[py][px]) stop = FALSE;
+	}
+
+	if (stop) return (TRUE);
+
+	/* break run when leaving trap detected region */
+	if ((disturb_trap_detect || alert_trap_detect)
+	    && p_ptr->dtrap && !(cave[py][px].info & CAVE_IN_DETECT))
+	{
+		/* No duplicate warning */
+		p_ptr->dtrap = FALSE;
+
+		/* You are just on the edge */
+		if (!(cave[py][px].info & CAVE_UNSAFE))
+		{
+			if (alert_trap_detect)
+			{
+#ifdef JP
+				msg_print("* :ϥȥåפδϰϳǤ *");
+#else
+				msg_print("*Leaving trap detect region!*");
+#endif
+			}
+
+			if (disturb_trap_detect)
+			{
+				/* Break Run */
+				return(TRUE);
+			}
+		}
+	}
+
+	/* Cannot travel when blind */
+	if (p_ptr->blind || no_lite())
+	{
+#ifdef JP
+		msg_print("ܤʤ");
+#else
+		msg_print("You cannot see!");
+#endif
+		return (TRUE);
+	}
+
+	/* Look at every newly adjacent square. */
+	for (i = -max; i <= max; i++)
+	{
+		/* New direction */
+		new_dir = cycle[chome[prev_dir] + i];
+
+		/* New location */
+		row = py + ddy[new_dir];
+		col = px + ddx[new_dir];
+
+		/* Access grid */
+		c_ptr = &cave[row][col];
+
+
+		/* Visible monsters abort running */
+		if (c_ptr->m_idx)
+		{
+			monster_type *m_ptr = &m_list[c_ptr->m_idx];
+
+			/* Visible monster */
+			if (m_ptr->ml) return (TRUE);
+		}
+	}
+
+	/* Failure */
+	return (FALSE);
+}
+
+
+/*
+ * Travel command
+ */
+void travel_step(void)
+{
+	int i;
+	int dir = travel.dir;
+	int old_run = travel.run;
+
+	find_prevdir = dir;
+
+	/* disturb */
+	if (travel_test())
+	{
+		disturb(0, 0);
+		return;
+	}
+
+	energy_use = 100;
+
+	for (i = 1; i <= 9; i++)
+	{
+		if (i == 5) continue;
+
+		if (travel.cost[py+ddy[i]][px+ddx[i]] < travel.cost[py+ddy[dir]][px+ddx[dir]])
+		{
+			dir = i;
+		}
+	}
+
+	/* Close door */
+	if (!easy_open && (cave[py+ddy[dir]][px+ddx[dir]].feat == FEAT_DOOR_HEAD))
+	{
+		disturb(0, 0);
+		return;
+	}
+
+	travel.dir = dir;
+	move_player(dir, easy_disarm);
+	travel.run = old_run;
+
+	if ((py == travel.y) && (px == travel.x))
+		travel.run = 0;
+	else
+		travel.run--;
+}
+#endif
