@@ -52,7 +52,6 @@ void do_cmd_go_up(void)
 
 		/* Leaving */
 		p_ptr->leaving = TRUE;
-		p_ptr->leftbldg = TRUE;
 
 		p_ptr->oldpx = 0;
 		p_ptr->oldpy = 0;
@@ -199,7 +198,6 @@ void do_cmd_go_down(void)
 
 		/* Leaving */
 		p_ptr->leaving = TRUE;
-		p_ptr->leftbldg = TRUE;
 
 		p_ptr->oldpx = 0;
 		p_ptr->oldpy = 0;
@@ -365,8 +363,7 @@ static s16b chest_check(int y, int x)
 {
 	cave_type *c_ptr = &cave[y][x];
 
-	s16b this_o_idx, next_o_idx = 0;
-
+	s16b this_o_idx, next_o_idx;
 
 	/* Scan all objects in the grid */
 	for (this_o_idx = c_ptr->o_idx; this_o_idx; this_o_idx = next_o_idx)
@@ -380,7 +377,7 @@ static s16b chest_check(int y, int x)
 		next_o_idx = o_ptr->next_o_idx;
 
 		/* Skip unknown chests XXX XXX */
-		/* if (!o_ptr->marked) continue; */
+		/* if (!(o_ptr->marked & OM_FOUND)) continue; */
 
 		/* Check for chest */
 		if (o_ptr->tval == TV_CHEST) return (this_o_idx);
@@ -1359,7 +1356,7 @@ static bool do_cmd_tunnel_aux(int y, int x)
 	else if ((c_ptr->feat >= FEAT_MAGMA) &&
 	    (c_ptr->feat <= FEAT_QUARTZ_K))
 	{
-		bool okay = FALSE;
+		bool okay;
 		bool gold = FALSE;
 		bool hard = FALSE;
 
@@ -2703,7 +2700,7 @@ void do_cmd_stay(int pickup)
 		disturb(0, 0);
 
 		/* Hack -- enter store */
-		command_new = 253;
+		command_new = SPECIAL_KEY_STORE;
 	}
 
 	/* Hack -- enter a building if we are on one -KMW- */
@@ -2714,7 +2711,7 @@ void do_cmd_stay(int pickup)
 		disturb(0, 0);
 
 		/* Hack -- enter building */
-		command_new = 254;
+		command_new = SPECIAL_KEY_BUILDING;
 	}
 
 	/* Exit a quest if reach the quest exit */
@@ -2732,7 +2729,7 @@ void do_cmd_stay(int pickup)
 #else
 			msg_print("You accomplished your quest!");
 #endif
-
+			sound(SOUND_QUEST);
 			msg_print(NULL);
 		}
 
@@ -2791,6 +2788,8 @@ void do_cmd_rest(void)
 		}
 	}
 
+	/* Hex */
+	if (p_ptr->keep_magic) (void)stop_hex_spell_all();
 
 	/* Paranoia */
 	if (command_arg > 9999) command_arg = 9999;
@@ -2851,16 +2850,21 @@ static bool test_hit_fire(int chance, int ac, int vis)
  */
 static int breakage_chance(object_type *o_ptr)
 {
-	int shoot_bonus;
+	int shoot_bonus = 0;
 
 	/* Culcurate class bonus */
 	switch (p_ptr->pclass) {
-		case CLASS_RANGER:
-			shoot_bonus = (p_ptr->lev - 1) / 7;
-			break;
 		case CLASS_ARCHER:
 			shoot_bonus = (p_ptr->lev - 1) / 7 + 4;
 			break;
+		case CLASS_SNIPER:
+			if (snipe_type == SP_KILL_WALL) return (100);
+			if (snipe_type == SP_EXPLODE) return (100);
+			if (snipe_type == SP_PIERCE) return (100);
+			if (snipe_type == SP_FINAL) return (100);
+			if (snipe_type == SP_EVILNESS) return (40);
+			if (snipe_type == SP_HOLYNESS) return (40);
+			break;
 		default:
 			shoot_bonus = 0;
 	}
@@ -2928,7 +2932,7 @@ static s16b critical_shot(object_type *o_ptr, int chance,
 
 	chance2 = chance + sleeping_bonus;
 	stick = is_stick(o_ptr);
-	object_desc(o_name, o_ptr, FALSE, 3);
+	object_desc(o_name, o_ptr, OD_OMIT_PREFIX);
 	monster_desc(m_name, m_ptr, FALSE);
 
 	if (!visible)
@@ -2941,10 +2945,10 @@ static s16b critical_shot(object_type *o_ptr, int chance,
 	}
 
 	/* Extract "shot" power */
-	i = (o_ptr->weight + (chance2 * 4) + (p_ptr->lev * 2));
+	i = (o_ptr->weight + (chance2 * 2) + (p_ptr->lev * 2));
 
 	/* Critical hit */
-	if (randint1(4000) <= i)
+	if (randint1(5000) <= i)
 	{
 		/* Encourage the player to throw weapons at sleeping
 		 * monsters. -LM-
@@ -3033,7 +3037,7 @@ static s16b critical_shot(object_type *o_ptr, int chance,
  * Note that most brands and slays are x2, except Slay Animal (x2.5),
  * Slay Evil (x2), and Kill dragon (x3). -SF-
  */
-s16b tot_dam_aux_shot(object_type *o_ptr, int tdam, monster_type *m_ptr)
+static s16b tot_dam_aux_shot(object_type *o_ptr, int tdam, monster_type *m_ptr)
 {
 	int mult = 10;
 
@@ -3374,6 +3378,9 @@ s16b tot_dam_aux_shot(object_type *o_ptr, int tdam, monster_type *m_ptr)
 		}
 	}
 
+	/* Sniper */
+	if (snipe_type) mult = tot_dam_aux_snipe(mult, m_ptr);
+
 	/* Return the total damage */
 	return (tdam * mult / 10);
 }
@@ -3432,10 +3439,10 @@ static void draw_firing_missile(object_type *o_ptr, int y, int x, int msec)
  *
  * Note that Bows of "Extra Shots" give an extra shot.
  */
-void do_cmd_fire_aux(int item, object_type *j_ptr)
+int do_cmd_fire_aux(int item, object_type *j_ptr)
 {
 	int dir;
-	int j, y, x, ny, nx, ty, tx;
+	int j, y, x, ny, nx, ty, tx, prev_y, prev_x;
 
 	int armour, bonus, chance;
 
@@ -3488,8 +3495,11 @@ void do_cmd_fire_aux(int item, object_type *j_ptr)
 		o_ptr = &o_list[0 - item];
 	}
 
+	/* Sniper */
+	if ((snipe_type == SP_DOUBLE) && (o_ptr->number < 2)) snipe_type = SP_NONE;
+
 	/* Describe the object */
-	object_desc(o_name, o_ptr, FALSE, 3);
+	object_desc(o_name, o_ptr, OD_OMIT_PREFIX);
 
 	/* Use the proper number of shots */
 	thits = p_ptr->num_fire;
@@ -3498,7 +3508,7 @@ void do_cmd_fire_aux(int item, object_type *j_ptr)
 	tdam = damroll(o_ptr->dd, o_ptr->ds) + o_ptr->to_d + j_ptr->to_d;
 
 	/* Actually "fire" the object. */
-	bonus = (p_ptr->to_h + o_ptr->to_h + j_ptr->to_h);
+	bonus = (p_ptr->to_b + o_ptr->to_h + j_ptr->to_h);
 	chance = (p_ptr->skill_thb + (bonus * BTH_PLUS_ADJ));
 
 	energy_use = bow_energy(j_ptr->sval);
@@ -3513,28 +3523,55 @@ void do_cmd_fire_aux(int item, object_type *j_ptr)
 	tdam *= tmul;
 	tdam /= 100;
 
+	/* Get extra damage from concentration */
+	if (p_ptr->concent) tdam = boost_concentration_damage(tdam);
+
 	/* Base range */
 	tdis = 10 + tmul / 40;
 
-	/* Take a (partial) turn */
-	energy_use = (energy_use * 100 / thits);
-
+	/* Get a direction (or cancel) */
 	project_length = tdis + 1;
 
-	/* Get a direction (or cancel) */
 	if (!get_aim_dir(&dir))
 	{
 		energy_use = 0;
-		return;
+		if (snipe_type == SP_AWAY) snipe_type = SP_NONE;
+		return (FALSE);
 	}
 
+	/* Start at the player */
+	y = py;
+	x = px;
+
+	/* Predict the "target" location */
+	ty = py + 99 * ddy[dir];
+	tx = px + 99 * ddx[dir];
+
+	/* Check for "target request" */
+	if ((dir == 5) && target_okay())
+	{
+		tx = target_col;
+		ty = target_row;
+	}
+
+	project_length = 0;
+
+	if ((tx == px) && (ty == py))
+	{
+		energy_use = 0;
+		return (FALSE);
+	}
+
+	/* Take a (partial) turn */
+	energy_use = (energy_use * 100 / thits);
+
 	/* XTRA HACK BARD_ARROW */
 	if (randint1(3) != 1 && o_ptr->name1 == ART_BARD_ARROW)
 	{
 		special_hit = TRUE;
 
 		/* Describe the object */
-		object_desc(o_name, o_ptr, FALSE, 0);
+		object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 		/* Let player know that weapon is activated. */
 #ifdef JP
@@ -3591,29 +3628,15 @@ void do_cmd_fire_aux(int item, object_type *j_ptr)
 		set_cut(randint1(tdam * 3));
 
 		/* That ends that shot! */
-		return;
+		return (TRUE);
 	}
 
-	/* Start at the player */
-	y = py;
-	x = px;
-
-	/* Predict the "target" location */
-	ty = py + 99 * ddy[dir];
-	tx = px + 99 * ddx[dir];
-
-	/* Check for "target request" */
-	if ((dir == 5) && target_okay())
-	{
-		tx = target_col;
-		ty = target_row;
-	}
-
-	project_length = 0;
-
 	/* Hack -- Handle stuff */
 	handle_stuff();
 
+	/* Save the old location */
+	prev_y = y;
+	prev_x = x;
 
 	/* Travel until stopped */
 	for (cur_dis = 0; cur_dis <= tdis; )
@@ -3631,15 +3654,60 @@ void do_cmd_fire_aux(int item, object_type *j_ptr)
 
 		/* Stopped by walls/doors */
 		c_ptr = &cave[ny][nx];
-		if (!cave_floor_grid(c_ptr) && !c_ptr->m_idx) break;
+		if (!cave_floor_grid(c_ptr) && !c_ptr->m_idx)
+		{
+			if (snipe_type == SP_KILL_WALL )
+			{
+				if (cave_perma_grid(c_ptr)) break;
+#ifdef JP
+				if (c_ptr->info & CAVE_MARK) msg_print("䤬դä");
+#else
+				if (c_ptr->info & CAVE_MARK) msg_print("Wall rocks were shattered.");
+#endif
+				/* Forget the wall */
+				c_ptr->info &= ~(CAVE_MARK);
+
+				p_ptr->update |= (PU_VIEW | PU_LITE | PU_FLOW | PU_MON_LITE);
+
+				/* Destroy the wall */
+				cave_set_feat(ny, nx, FEAT_FLOOR);
+			}
+			break;
+		}
 
 		/* Advance the distance */
 		cur_dis++;
 
+		/* Sniper */
+		if (snipe_type == SP_LITE)
+		{
+			cave[ny][nx].info |= (CAVE_GLOW);
+
+			/* Notice */
+			note_spot(ny, nx);
+
+			/* Redraw */
+			lite_spot(ny, nx);
+		}
 
 		/* Draw a missile if the player can see it */
 		draw_firing_missile(i_ptr, ny, nx, msec);
 
+		if (snipe_type == SP_EVILNESS)
+		{
+			cave[ny][nx].info &= ~(CAVE_GLOW | CAVE_MARK);
+
+			/* Notice */
+			note_spot(ny, nx);
+
+			/* Redraw */
+			lite_spot(ny, nx);
+		}
+
+		/* Save the old location */
+		prev_y = y;
+		prev_x = x;
+
 		/* Save the new location */
 		x = nx;
 		y = ny;
@@ -3689,6 +3757,11 @@ void do_cmd_fire_aux(int item, object_type *j_ptr)
 			/* Weapons of velocity sometimes almost negate monster armour. */
 			if (special_hit) armour /= 3;
 			if (superb_shot) armour /= 2;
+			if (p_ptr->concent)
+			{
+				armour *= (30 - p_ptr->concent * 2);
+				armour /= 30;
+			}
 
 			/* Did we hit it (penalize range) */
 			if (test_hit_fire(chance2 + sleeping_bonus, armour, m_ptr->ml))
@@ -3746,6 +3819,16 @@ void do_cmd_fire_aux(int item, object_type *j_ptr)
 #endif
 				}
 
+				/* Sniper */
+				if (snipe_type == SP_EXPLODE)
+				{
+					u16b flg = (PROJECT_STOP | PROJECT_JUMP | PROJECT_KILL | PROJECT_GRID);
+
+					sound(SOUND_EXPLODE);
+					project(0, ((p_ptr->concent + 1) / 2 + 1), ny, nx, tdam, GF_MISSILE, flg);
+					break;
+				}
+
 				/* Hit the monster, check for death */
 				if (mon_take_hit(c_ptr->m_idx, tdam, &fear, note_dies))
 				{
@@ -3797,9 +3880,95 @@ void do_cmd_fire_aux(int item, object_type *j_ptr)
 						m_ptr->target_y = py;
 						m_ptr->target_x = px;
 					}
+
+					/* Sniper */
+					if (snipe_type == SP_RUSH)
+					{
+						int n = randint1(5) + 3;
+						int m_idx = c_ptr->m_idx;
+						cave_type *nc_ptr;
+
+						for ( ; cur_dis <= tdis; )
+						{
+							int ox = nx;
+							int oy = ny;
+
+							if (!n) break;
+
+							/* Calculate the new location (see "project()") */
+							mmove2(&ny, &nx, py, px, ty, tx);
+
+							/* Stopped by wilderness boundary */
+							if (!in_bounds2(ny, nx)) break;
+
+							/* Stopped by walls/doors */
+							nc_ptr = &cave[ny][nx];
+							if (!cave_floor_grid(nc_ptr)) break;
+
+							/* Stopped by monsters */
+							if (nc_ptr->m_idx) break;
+
+							cave[ny][nx].m_idx = m_idx;
+							cave[oy][ox].m_idx = 0;
+
+							m_ptr->fx = nx;
+							m_ptr->fy = ny;
+
+							/* Update the monster (new location) */
+							update_mon(c_ptr->m_idx, TRUE);
+
+							lite_spot(ny, nx);
+							lite_spot(oy, ox);
+
+							Term_fresh();
+							Term_xtra(TERM_XTRA_DELAY, msec);
+
+							x = nx;
+							y = ny;
+							cur_dis++;
+							n--;
+						}
+					}
+
+					/* Sniper */
+					if (snipe_type == SP_PARALYZE)
+					{
+						int mlev = (r_ptr->flags1 & RF1_UNIQUE) ? (r_ptr->level * 2) : r_ptr->level;
+
+						if ((r_ptr->flags3 & RF3_NO_SLEEP) ||
+							(mlev > (10 + randint1(p_ptr->concent * 15))))
+						{
+							if (r_ptr->flags3 & RF3_NO_SLEEP)
+							{
+								if (is_seen(m_ptr)) r_ptr->r_flags3 |= (RF3_NO_SLEEP);
+							}
+#ifdef JP
+							msg_format("%sˤϸ̤ʤä", r_name + r_ptr->name);
+#else
+							msg_format("%s is unaffected!", r_name + r_ptr->name);
+#endif
+						}
+						else
+						{
+							m_ptr->csleep = 500;
+#ifdef JP
+							msg_format("%s̲Ǥޤä", r_name + r_ptr->name);
+#else
+							msg_format("%s falls asleep!", r_name + r_ptr->name);
+#endif
+							}
+					}
 				}
 			}
 
+			/* Sniper */
+			if (snipe_type == SP_PIERCE)
+			{
+				if(p_ptr->concent < 1) break;
+				p_ptr->concent--;
+				continue;
+			}
+
 			/* Stop looking */
 			break;
 		}
@@ -3821,14 +3990,14 @@ void do_cmd_fire_aux(int item, object_type *j_ptr)
 			{
 				a_info[i_ptr->name1].cur_num = 0;
 			}
-			return;
+			return (TRUE);
 		}
 
 		o_ptr = &o_list[ o_idx ];
 		object_copy(o_ptr, i_ptr);
 
 		/* Forget mark */
-		o_ptr->marked = 0;
+		o_ptr->marked &= OM_TOUCHED;
 
 		/* Forget location */
 		o_ptr->iy = o_ptr->ix = 0;
@@ -3842,13 +4011,25 @@ void do_cmd_fire_aux(int item, object_type *j_ptr)
 		/* Carry object */
 		m_ptr->hold_o_idx = o_idx;
 	}
-	else
+	else if (cave_floor_bold(y, x))
+	{
 		/* Drop (or break) near that location */
 		(void)drop_near(i_ptr, j, y, x);
+	}
+	else
+	{
+		/* Drop (or break) near that location */
+		(void)drop_near(i_ptr, j, prev_y, prev_x);
+	}
+
+	/* Sniper */
+	if ((snipe_type != SP_DOUBLE) && (p_ptr->concent)) reset_concentration(FALSE);
+
+	return (TRUE);
 }
 
 
-void do_cmd_fire(void)
+int do_cmd_fire(void)
 {
 	int item;
 	object_type *j_ptr;
@@ -3865,7 +4046,7 @@ void do_cmd_fire(void)
 #else
 		msg_print("You have nothing to fire with.");
 #endif
-		return;
+		return (FALSE);
 	}
 
 
@@ -3881,10 +4062,36 @@ void do_cmd_fire(void)
 	s = "You have nothing to fire.";
 #endif
 
-	if (!get_item(&item, q, s, (USE_INVEN | USE_FLOOR))) return;
+	if (!get_item(&item, q, s, (USE_INVEN | USE_FLOOR)))
+	{
+		return (FALSE);
+	}
 
 	/* Fire the item */
-	do_cmd_fire_aux(item, j_ptr);
+	if (!do_cmd_fire_aux(item, j_ptr)) return (FALSE);
+
+	/* Sniper */
+	if (snipe_type == SP_DOUBLE)
+	{
+		snipe_type = SP_NONE;
+		(void)do_cmd_fire_aux(item, j_ptr);
+	}
+	if (snipe_type == SP_AWAY)
+	{
+		teleport_player(10 + (p_ptr->concent * 2));
+	}
+	if (snipe_type == SP_FINAL)
+	{
+#ifdef JP
+		msg_print("ͷȿưΤ򽱤ä");
+#else
+		msg_print("A reactionary of shooting attacked you. ");
+#endif
+		(void)set_slow(p_ptr->slow + randint0(10) + 10);
+		(void)set_stun(p_ptr->stun + randint1(40));
+	}
+
+	return (TRUE);
 }
 
 
@@ -3900,7 +4107,7 @@ void do_cmd_fire(void)
 static void do_cmd_throw_aux(int item, int mult)
 {
 	int dir;
-	int j, y, x, ny, nx, ty, tx;
+	int j, y, x, ny, nx, ty, tx, prev_y, prev_x;
 	int ry[19], rx[19];
 	int chance, chance2, tdis;
 	int mul, div;
@@ -3973,7 +4180,7 @@ static void do_cmd_throw_aux(int item, int mult)
 	if (q_ptr->name1 == ART_MJOLLNIR) return_when_thrown = TRUE;
 
 	/* Description */
-	object_desc(o_name, q_ptr, FALSE, 3);
+	object_desc(o_name, q_ptr, OD_OMIT_PREFIX);
 
 	/* Extract a "distance multiplier" */
 	/* Changed for 'launcher' mutation */
@@ -3990,9 +4197,9 @@ static void do_cmd_throw_aux(int item, int mult)
 	if (tdis > mul) tdis = mul;
 
 	if (f2 & (TR2_THROW))
-		chance = ((p_ptr->skill_tht) + ((p_ptr->to_h + q_ptr->to_h) * BTH_PLUS_ADJ));
+		chance = ((p_ptr->skill_tht) + ((p_ptr->to_b + q_ptr->to_h) * BTH_PLUS_ADJ));
 	else
-		chance = ((p_ptr->skill_tht) + (p_ptr->to_h * BTH_PLUS_ADJ));
+		chance = ((p_ptr->skill_tht) + (p_ptr->to_b * BTH_PLUS_ADJ));
 
 	project_length = tdis + 1;
 	
@@ -4037,6 +4244,9 @@ static void do_cmd_throw_aux(int item, int mult)
 	/* Hack -- Handle stuff */
 	handle_stuff();
 
+	/* Save the old location */
+	prev_y = y;
+	prev_x = x;
 
 	/* Travel until stopped */
 	for (cur_dis = 0; cur_dis <= tdis; )
@@ -4070,6 +4280,10 @@ static void do_cmd_throw_aux(int item, int mult)
 		/* Draw a missile if the player can see it */
 		draw_firing_missile(q_ptr, ny, nx, msec);
 
+		/* Save the old location */
+		prev_y = y;
+		prev_x = x;
+
 		/* Save the new location */
 		x = nx;
 		y = ny;
@@ -4295,7 +4509,7 @@ static void do_cmd_throw_aux(int item, int mult)
 
 		j = -1;
 		back_chance = randint1(30) + 20 + ((int)(adj_dex_th[p_ptr->stat_ind[A_DEX]]) - 128);
-		object_desc(o_name, q_ptr, FALSE, 0);
+		object_desc(o_name, q_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 		if((back_chance > 30) && !one_in_(100))
 		{
@@ -4386,8 +4600,20 @@ static void do_cmd_throw_aux(int item, int mult)
 		activate_light_sabre(q_ptr, FALSE);
 
 	/* Drop (or break) near that location */
-	if (do_drop) (void)drop_near(q_ptr, j, y, x);
-	
+	if (do_drop)
+	{
+		if (cave_floor_bold(y, x))
+		{
+			/* Drop (or break) near that location */
+			(void)drop_near(q_ptr, j, y, x);
+		}
+		else
+		{
+			/* Drop (or break) near that location */
+			(void)drop_near(q_ptr, j, prev_y, prev_x);
+		}
+	}
+
 	p_ptr->redraw |= (PR_EQUIPPY);
 }
 
@@ -4413,3 +4639,161 @@ void do_cmd_throw(int mult)
 
 	do_cmd_throw_aux(item, mult);
 }
+
+
+#ifdef TRAVEL
+/*
+ * Hack: travel command
+ */
+#define TRAVEL_UNABLE 9999
+
+static int flow_head = 0;
+static int flow_tail = 0;
+static s16b temp2_x[MAX_SHORT];
+static s16b temp2_y[MAX_SHORT];
+
+/* Hack: forget the "flow" information */
+void forget_travel_flow(void)
+{
+	int x, y;
+
+	/* Check the entire dungeon */
+	for (y = 0; y < cur_hgt; y++)
+	{
+		for (x = 0; x < cur_wid; x++)
+		{
+			/* Forget the old data */
+			travel.cost[y][x] = TRAVEL_UNABLE;
+		}
+	}
+}
+
+static bool travel_flow_aux(int y, int x, int n, bool wall)
+{
+	cave_type *c_ptr = &cave[y][x];
+	int old_head = flow_head;
+
+	n = n % TRAVEL_UNABLE;
+
+	/* Ignore out of bounds */
+	if (!in_bounds(y, x)) return wall;
+
+	/* Ignore "pre-stamped" entries */
+	if (travel.cost[y][x] != TRAVEL_UNABLE) return wall;
+
+	/* Ignore "walls" and "rubble" (include "secret doors") */
+	if (((c_ptr->feat >= FEAT_RUBBLE) && (c_ptr->feat <= FEAT_PERM_SOLID)) ||
+		(c_ptr->feat == FEAT_SECRET) ||
+		((!p_ptr->ffall) && (c_ptr->feat == FEAT_DARK_PIT)))
+	{
+		if (!wall) return wall;
+	}
+	else
+	{
+		wall = FALSE;
+	}
+
+	/* Save the flow cost */
+	travel.cost[y][x] = n;
+	if (wall) travel.cost[y][x] += TRAVEL_UNABLE;
+
+	/* Enqueue that entry */
+	temp2_y[flow_head] = y;
+	temp2_x[flow_head] = x;
+
+	/* Advance the queue */
+	if (++flow_head == MAX_SHORT) flow_head = 0;
+
+	/* Hack -- notice overflow by forgetting new entry */
+	if (flow_head == flow_tail) flow_head = old_head;
+
+	return wall;
+}
+
+
+static void travel_flow(int ty, int tx)
+{
+	int x, y, d;
+	bool wall = FALSE;
+
+	/* Reset the "queue" */
+	flow_head = flow_tail = 0;
+
+	if (!cave_floor_bold(ty, tx)) wall = TRUE;
+
+	/* Add the player's grid to the queue */
+	wall = travel_flow_aux(ty, tx, 0, wall);
+
+	/* Now process the queue */
+	while (flow_head != flow_tail)
+	{
+		/* Extract the next entry */
+		y = temp2_y[flow_tail];
+		x = temp2_x[flow_tail];
+
+		/* Forget that entry */
+		if (++flow_tail == MAX_SHORT) flow_tail = 0;
+
+		/* Add the "children" */
+		for (d = 0; d < 8; d++)
+		{
+			/* Add that child if "legal" */
+			wall = travel_flow_aux(y + ddy_ddd[d], x + ddx_ddd[d], travel.cost[y][x] + 1, wall);
+		}
+	}
+
+	/* Forget the flow info */
+	flow_head = flow_tail = 0;
+}
+
+void do_cmd_travel(void)
+{
+	int x, y, i;
+	int dx, dy, sx, sy;
+
+	if (!tgt_pt(&x, &y)) return;
+
+	if ((x == px) && (y == py))
+	{
+#ifdef JP
+		msg_print("Ǥˤˤޤ");
+#else
+		msg_print("You are already there!!");
+#endif
+		return;
+	}
+
+	if ((cave[y][x].info & CAVE_MARK) && !cave_floor_bold(y, x))
+	{
+#ifdef JP
+		msg_print("ˤϹԤȤǤޤ");
+#else
+		msg_print("You cannot travel there!");
+#endif
+		return;
+	}
+
+	travel.x = x;
+	travel.y = y;
+
+	forget_travel_flow();
+	travel_flow(y, x);
+
+	/* Travel till 255 steps */
+	travel.run = 255;
+
+	/* Paranoia */
+	travel.dir = 0;
+
+	/* Decides first direction */
+	dx = abs(px - x);
+	dy = abs(py - y);
+	sx = ((x == px) || (dx < dy)) ? 0 : ((x > px) ? 1 : -1);
+	sy = ((y == py) || (dy < dx)) ? 0 : ((y > py) ? 1 : -1);
+
+	for (i = 1; i <= 9; i++)
+	{
+		if ((sx == ddx[i]) && (sy == ddy[i])) travel.dir = i;
+	}
+}
+#endif
