@@ -125,6 +125,42 @@ static const char *spell_tips[MAX_REALM][32] =
 		"Ǽ٤°Ĥ롣",
 		"֡դACˡɸǽϤ徺롣"
 	},
+	{
+		"Ϥ򾯤롣",
+		"ʡˤ깶٤ɸϤ夬롣",
+		"볦Υ󥹥ư٤롣",
+		"ΥȤˤޤȤ®٤®ʤ롣",
+		"볦Υ󥹥̤ǤΥ᡼Ϳ롣",
+		"ѼԤϤ徺롣",
+		"Ƥ",
+		"Ϥμٰʥ󥹥Τ롣",
+		"Źؤ롣",
+		"ɹΥȤˤޤȤɸϤ徺롣",
+
+		"Ϥ¿롣",
+		"1ΤΥ󥹥ܤޥظƤӴ󤻤롣",
+		"ʸӾߤ뤳Ȥʤθ̤뤳ȤǤ롣",
+		"볦Υ󥹥̤̿ϵۼΥ᡼Ϳ롣Ϳ᡼ʬϤ롣",
+		"ιϤ夲롣ڤ̣˱Ϳ᡼徺ɤʥ󥹥Ф᡼2ܤˤʤ롣",
+		"Ϲؤ롣",
+		"⤷ݥ󥹥𤵤롣",
+		"ѼԤϡѤѵϤ徺롣ξ¤ 1 ä롣",
+		"볦Υ󥹥ƥݡȤ롣",
+		"볦Υ󥹥ΥƥݡȤ˳Хꥢĥ롣",
+
+		"γ󥹥˻ߤ롣",
+		"Ϥ롣",
+		"β롣",
+		"ˡƻϤƽŶ롣",
+		"줿μۼϤ롣",
+		"иͤ褷ǽͤ롣",
+		"۷°ǹ⤹롣",
+		"볦Υ󥹥ۯ۰Ȥ롣",
+		"󥹥٤Υޥ˽ְִư롣",
+		"ǷˡǼ᡼򡢹⸵Υ󥹥ˤͿ롣",
+		"볦Υ󥹥ˡ˳Хꥢĥ롣",
+		"ˡޤǼ᡼˱ϤˡƤоݤΥ󥹥λ֤ġ",
+	}
 #else
 	{
 		"Detects all evil monsters in your vicinity.",
@@ -234,6 +270,42 @@ static const char *spell_tips[MAX_REALM][32] =
 		"Makes current weapon an evil slayer.",
 		"Gives ultimate resistance, bonus to AC and speed."
 	},
+	{
+		"Heals cut and HP a little.",
+		"Attempts to increase +to_hit of a weapon and AC",
+		"Makes all monsters slow in your sight.",
+		"Gives fire aura and regeneration.",
+		"Deals few damages of poison to all monsters in your sight.",
+		"Attempts to increase your strength.",
+		"Curses your weapon.",
+		"Detects evil monsters.",
+		"Gives resistance to dark.",
+		"Gives fire aura and bonus to AC.",
+
+		"Heals cut and HP more.",
+		"Teleports a monster close to you.",
+		"Quaffs a potion without canceling of casting a spell.",
+		"Deals few dameges of drain life to all monsters in your sight.",
+		"Gives vorpal ability to your weapon. Increases damages by your weapon acccording to curse of your weapon.",
+		"Gives resistance to nether.",
+		"Confuses a monster when you attack.",
+		"Attempts to increases your strength, dexterity and constitusion.",
+		"Teleport all monsters away in your sight.",
+		"Obstructs all teleportations by monsters in your sight.",
+
+		"Obstructs all multiplying by monsters in entire floor.",
+		"Heals cut and HP greatry.",
+		"Makes you berserk.",
+		"Recharges a magic device.",
+		"Drains curse on your weapon and heals SP a little.",
+		"Restores life energy and status.",
+		"Gives vampiric ability to your weapon.",
+		"Stuns all monsters in your sight.",
+		"Teleports you close to a monster.",
+		"Returns same damage which you got to the monster which damaged you.",
+		"Obstructs all magic spell of monsters in your sight.",
+		"Fires magic ball to revenge after few turns.",
+	},
 #endif
 };
 
@@ -1715,6 +1787,9 @@ void do_cmd_cast(void)
 		case REALM_MUSOU: /* * MUSOU * */
 			cast = cast_musou_spell(spell);
 			break;
+		case REALM_HEX: /* * HEX * */
+			cast = cast_hex_spell(spell);	/* HEX */
+			break;
 		default:
 			cast = FALSE;
 			msg_format("You cast a spell from an unknown realm: realm %d, spell %d.", realm, spell);
@@ -1827,6 +1902,180 @@ void do_cmd_pray(void)
 }
 
 
+
+int calculate_upkeep(void)
+{
+	int i;
+
+	monster_type    *m_ptr;
+	monster_race    *r_ptr;
+
+	int old_total_friends = total_friends; 
+	s32b old_friend_align = friend_align;
+
+	/* Clear some variables */
+	total_friends = 0;
+	total_friend_levels = 0;
+	friend_align = 0;
+
+	for (i = m_max - 1; i >= 1; i--)
+	{
+		/* Access the monster */
+		m_ptr = &m_list[i];
+		r_ptr = &r_info[m_ptr->r_idx];
+
+		/* Ignore "dead" monsters */
+		if (!m_ptr->r_idx) continue;
+
+		/* Calculate "upkeep" for pets */
+		if (is_pet(m_ptr))
+		{
+			total_friends++;
+			if (r_ptr->flags1 & (RF1_UNIQUE))
+				total_friend_levels += (r_ptr->level + 5) * 10;
+			else
+				total_friend_levels += r_ptr->level;
+
+			/* Determine pet alignment */
+			if (r_ptr->flags3 & RF3_GOOD)
+			{
+				friend_align += r_ptr->level;
+			}
+			else if (r_ptr->flags3 & RF3_EVIL)
+			{
+				friend_align -= r_ptr->level;
+			}
+		}
+	}
+
+	if (old_friend_align != friend_align) p_ptr->update |= (PU_BONUS);
+	
+	if (total_friends)
+	{
+#ifdef TRACK_FRIENDS
+		if (wizard)
+#ifdef JP
+			msg_format("ͧŪ󥹥: %d ", total_friends);
+#else
+			msg_format("Total friends: %d.", total_friends);
+#endif
+
+#endif /* TRACK_FRIENDS */
+
+		if (total_friends)
+		{
+			int upkeep_factor = (total_friend_levels - (p_ptr->lev * 80 / cp_ptr->pet_upkeep_div));
+
+			if (upkeep_factor > 1000) upkeep_factor = 1000;
+			else if (upkeep_factor < 0) upkeep_factor = 0;
+
+#ifdef TRACK_FRIENDS
+			if (wizard)
+#ifdef JP
+			msg_format("٥ %d, ݻͣ %d", total_friend_levels, upkeep_factor);
+#else
+			msg_format("Levels %d, upkeep %d", total_friend_levels, upkeep_factor);
+#endif
+
+#endif /* TRACK_FRIENDS */
+
+			return upkeep_factor;
+		}
+	}
+
+	return 0;
+}
+
+/*
+ * Dismiss pets
+ */
+void do_cmd_pet_dismiss(void)
+{
+	int pet_ctr;
+	bool all_pets = FALSE;
+	int Dismissed = 0;
+	monster_type *m_ptr;
+
+#ifdef JP
+	if (get_check("٤ƤΥڥåȤޤ")) all_pets = TRUE;
+#else
+	if (get_check("Dismiss all pets? ")) all_pets = TRUE;
+#endif
+
+	/* Process the monsters (backwards) */
+	for (pet_ctr = m_max - 1; pet_ctr >= 1; pet_ctr--)
+	{
+		/* Access the monster */
+		m_ptr = &m_list[pet_ctr];
+
+		if (is_pet(m_ptr))
+		{
+			bool delete_this = FALSE;
+
+			if (all_pets)
+				delete_this = TRUE;
+			else
+			{
+				char friend_name[80], check_friend[80];
+				monster_desc(friend_name, m_ptr, 0x80);
+
+				/* Hack -- health bar for this monster */
+				health_track(pet_ctr);
+
+				/* Hack -- handle stuff */
+				handle_stuff();
+
+#ifdef JP
+				sprintf(check_friend, "%sޤ [Yes/No/All]", friend_name);
+#else
+				sprintf(check_friend, "Dismiss %s? [Yes/No/All]", friend_name);
+#endif
+				prt(check_friend, 0, 0);
+
+				if (m_ptr->ml)
+					move_cursor_relative(m_ptr->fy, m_ptr->fx);
+
+				while (TRUE)
+				{
+					int ch = inkey();
+
+					if ((ch == 'Y') || (ch == 'y'))
+					{
+						delete_this = TRUE;
+						break;
+					}
+					else if ((ch == 'A') || (ch == 'a'))
+					{
+						delete_this = TRUE;
+						all_pets = TRUE;
+						break;
+					}
+					else if ((ch == ESCAPE) || (ch == 'N') || (ch == 'n'))
+						break;
+
+					bell();
+				}
+			}
+
+			if (delete_this)
+			{
+				delete_monster_idx(pet_ctr);
+				Dismissed++;
+			}
+		}
+	}
+
+	Term_erase(0, 0, 255);
+#ifdef JP
+	msg_format("%d ɤΥڥåȤޤ", Dismissed);
+#else
+	msg_format("You have dismissed %d pet%s.", Dismissed,
+		(Dismissed == 1 ? "" : "s"));
+#endif
+	return;
+}
+
+		
 /*
  * Issue a pet command
  */
@@ -1841,7 +2090,6 @@ void do_cmd_pet(void)
 	char			choice;
 	char			out_val[160];
 	int			pets = 0, pet_ctr;
-	bool			all_pets = FALSE;
 	monster_type	*m_ptr;
 
 	int mode = 0;
@@ -2116,54 +2364,7 @@ void do_cmd_pet(void)
 	{
 		case PET_DISMISS: /* Dismiss pets */
 		{
-			int Dismissed = 0;
-
-#ifdef JP
-			if (get_check("٤ƤΥڥåȤޤ")) all_pets = TRUE;
-#else
-			if (get_check("Dismiss all pets? ")) all_pets = TRUE;
-#endif
-
-			/* Process the monsters (backwards) */
-			for (pet_ctr = m_max - 1; pet_ctr >= 1; pet_ctr--)
-			{
-				/* Access the monster */
-				m_ptr = &m_list[pet_ctr];
-
-				if (is_pet(m_ptr))
-				{
-					bool delete_this = FALSE;
-
-					if (all_pets)
-						delete_this = TRUE;
-					else
-					{
-						char friend_name[80], check_friend[80];
-						monster_desc(friend_name, m_ptr, 0x80);
-#ifdef JP
-						sprintf(check_friend, "%sޤ ", friend_name);
-#else
-						sprintf(check_friend, "Dismiss %s? ", friend_name);
-#endif
-
-						if (get_check(check_friend))
-							delete_this = TRUE;
-					}
-
-					if (delete_this)
-					{
-						delete_monster_idx(pet_ctr);
-						Dismissed++;
-					}
-				}
-			}
-
-#ifdef JP
-			msg_format("%d ɤΥڥåȤޤ", Dismissed);
-#else
-			msg_format("You have dismissed %d pet%s.", Dismissed,
-				(Dismissed == 1 ? "" : "s"));
-#endif
+			do_cmd_pet_dismiss();
 			break;
 		}
 		/* Call pets */
