@@ -106,9 +106,12 @@
  */
 
 
-
 #include "angband.h"
 
+#ifdef HAVE_LIBSDL_MIXER
+#include "sdl_sound.h"
+#endif /* HAVE_LIBSDL_MIXER */
+
 
 #ifdef USE_X11
 
@@ -138,6 +141,9 @@ char *XSetIMValues(XIM, ...); /* Hack for XFree86 4.0 */
  */
 #define IGNORE_UNUSED_FUNCTIONS
 
+#ifdef HAVE_LIBSDL_MIXER
+static	bool no_cache_audio = FALSE;
+#endif /* HAVE_LIBSDL_MIXER */
 
 /*
  * Notes on Colors:
@@ -2328,6 +2334,12 @@ static errr Term_xtra_x11(int n, int v)
 
 		/* React to changes */
 		case TERM_XTRA_REACT: return (Term_xtra_x11_react());
+#ifdef HAVE_LIBSDL_MIXER
+		/* Play a sound */
+		case TERM_XTRA_SOUND :
+			if ( enable_sound ) { play_sound( v, no_cache_audio ); } 
+			return 0;
+#endif /* HAVE_LIBSDL_MIXER */
 	}
 
 	/* Unknown */
@@ -3004,6 +3016,15 @@ errr init_x11(int argc, char *argv[])
 			continue;
 		}
 
+#ifdef HAVE_LIBSDL_MIXER
+		if (prefix(argv[i], "-c"))
+		{
+			no_cache_audio = TRUE;
+			plog("Audio cache disabled");			
+			continue;		
+		}
+#endif /* HAVE_LIBSDL_MIXER */
+
 		plog_fmt("Ignoring option: %s", argv[i]);
 	}
 
@@ -3202,6 +3223,21 @@ errr init_x11(int argc, char *argv[])
 
 #endif /* USE_GRAPHICS */
 
+#ifdef HAVE_LIBSDL_MIXER
+	/* Load sound preferences if requested */
+	if (arg_sound)
+	{
+		if ( load_sound_prefs(no_cache_audio) != 0 ) 
+		{
+			enable_sound = 1;
+			/* plog("Loaded sound prefs OK!"); */
+		}
+		else
+		{
+			plog("Failed to load sound config");
+		}
+	}
+#endif  /* HAVE_LIBSDL_MIXER */
 
 	/* Success */
 	return (0);
