@@ -124,7 +124,7 @@ static grouper group_item[] =
 	{ TV_LIFE_BOOK,     "ˡ̿" },
 	{ TV_SORCERY_BOOK,  "ˡѡ" },
 	{ TV_MUSOU_BOOK,    "ˡ̵С" },
-	{ TV_MAGIC_BOOK,    "ˡʼѡ" },
+	{ TV_HEX_BOOK,    "ˡʼѡ" },
 
 	{ TV_CHEST,         "Ȣ" },
 	{ TV_FIGURINE,      "ͷ" },
@@ -170,7 +170,7 @@ static grouper group_item[] =
 	{ TV_LIFE_BOOK,     "Books (Life)" },
 	{ TV_SORCERY_BOOK,  "Books (Sorcery)" },
 	{ TV_MUSOU_BOOK,    "Books (Combat)" },
-	{ TV_MAGIC_BOOK,    "Books (Magic)" },
+	{ TV_HEX_BOOK,      "Books (Hex)" },
 
 	{ TV_CHEST,         "Chests" },
 	{ TV_FIGURINE,      "Magical Figurines" },
